﻿--[[

	Quest Completist - qcCollect.lua
	Written by: Alistair Maxwell

--]]

function qcWipeWorkingDB()

	wipe(qcWorkingDB)
	wipe(qcWorkingLog)

end

function qcMergeDB()

	qcMergeSVData()
	qcSetClassBits()
	qcSetQuestCategories()

end

function qcSetQuestCategories()

	local qcRecordCount = 0
	local qcInvalidCount = 0
	local qcChangeCount = 0
	table.insert(qcWorkingLog, "-----------------------")
	table.insert(qcWorkingLog, "PROCESSING ZONE ID's...")
	table.insert(qcWorkingLog, "-----------------------")

	for qcIndex, qcEntry in pairs(qcWorkingDB) do
		qcRecordCount = (qcRecordCount + 1)
		if (qcEntry[2][1] == 99999) then
			qcInvalidCount = (qcInvalidCount + 1)
			for qcCategoryIndex, qcCategoryEntry in ipairs(qcQuestCategories) do
				if (qcCategoryEntry[2] == qcEntry[1][4]) then
					qcChangeCount = (qcChangeCount + 1)
					table.insert(qcWorkingLog, "ZONE ID UPDATED FOR QUEST: " .. tostring(qcEntry[1][2]) .. " [" .. tostring(qcEntry[1][1]) .. "]")
					table.insert(qcWorkingLog, "    ZONE ID - ORIGINAL VALUE: '" .. tostring(qcEntry[2][1]) .. "' NEW VALUE: '" .. tostring(qcCategoryEntry[1]) .. "'")
					qcEntry[2][1] = qcCategoryEntry[1]
					break
				end
			end
		end
	end

	table.insert(qcWorkingLog, "NO VALID ZONE ID FOUND FOR THE FOLLOWING CATEGORIES:")
	for qcIndex, qcEntry in pairs(qcWorkingDB) do
		if (qcEntry[2][1] == 99999) then
			table.insert(qcWorkingLog, tostring(qcEntry[1][4]))
		end
	end

	print(tostring(qcRecordCount) .. " records were checked for invalid zone ID's. " .. tostring(qcInvalidCount) .. " invalid records were found. " .. tostring(qcChangeCount) .. " changes were made, leaving " .. tostring(qcInvalidCount - qcChangeCount) .. " invalid records remaining.")

end

function qcMergeSVData()

	for qcIndex, qcEntry in pairs(qcQuestDBv2) do
		table.insert(qcWorkingDB, qcIndex, qcEntry)
	end

	local qcNewCount = 0
	local qcRecordCount = 0
	table.insert(qcWorkingLog, "---------------------------")
	table.insert(qcWorkingLog, "PROCESSING QUEST RECORDS...")
	table.insert(qcWorkingLog, "---------------------------")

	for qcIndex, qcEntry in pairs(qcSVData) do
		qcRecordCount = (qcRecordCount + 1)
		if (qcWorkingDB[qcIndex] == nil) then --[[ The quest is brand new ]]--
			table.insert(qcWorkingDB, qcIndex, qcEntry)
			--[[ For new quests, we set the class and race for "everyone", but leave faction as recorded ]]--
			--[[ The idea is that i will manually claw these back as needed, and if i clawed back too much, the update section of the below code will add the required classes back on ]]--
			qcWorkingDB[qcIndex][4][2] = 4095
			qcWorkingDB[qcIndex][4][3] = 1023
			table.insert(qcWorkingLog, "NEW QUEST FOUND: " .. tostring(qcEntry[1][2]) .. " [" .. tostring(qcEntry[1][1]) .. "]")
			qcNewCount = (qcNewCount + 1)
		else --[[ The quest already exists - start updates ]]--
			table.insert(qcWorkingLog, "EXISTING QUEST FOUND: " .. tostring(qcWorkingDB[qcIndex][1][2]) .. " [" .. tostring(qcWorkingDB[qcIndex][1][1]) .. "]")
			--[[ First we want to see if we have all the information, or just what was gathered via QUEST_DETAIL ]]--
			if (qcEntry[1][4] == "<Category Unknown>") then
				table.insert(qcWorkingLog, "    PRELIMINARY DATA FOUND - SOME FIELDS WILL NOT BE UPDATED")
				--[[ If for some random reason the ID was not present, update it ]]--
				if (qcEntry[1][1] == nil) then qcEntry[1][1] = qcIndex end
				--[[ Quest name will not be updated as it will remove any tags already present ]]--
				--[[ Quest level will not be updated as it can only be known after accepting the quest ]]--
				--[[ Quest category will not be updated as it can only be known after accepting the quest ]]--
				--[[ Quest type will not be updated as it will overwrite any manually set types (eg. repeatables or specials) ]]--
				if (qcWorkingDB[qcIndex][2][1] ~= qcEntry[2][1]) then
					if (qcEntry[2][1] ~= 99999) then
						table.insert(qcWorkingLog, "    ZONE ID UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][2][1]) .. "' NEW VALUE: '" .. tostring(qcEntry[2][1]) .. "'")
						qcWorkingDB[qcIndex][1][4] = qcEntry[2][1]
					end
				end
				if (qcWorkingDB[qcIndex][3][1] ~= qcEntry[3][1]) then
					table.insert(qcWorkingLog, "    NPC ID UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][1]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][1]) .. "'")
					qcWorkingDB[qcIndex][3][1] = qcEntry[3][1]
				end
				if (qcWorkingDB[qcIndex][3][2] ~= qcEntry[3][2]) then
					table.insert(qcWorkingLog, "    NPC NAME UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][2]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][2]) .. "'")
					qcWorkingDB[qcIndex][3][2] = qcEntry[3][2]
				end
				if (qcWorkingDB[qcIndex][3][3] ~= qcEntry[3][3]) then
					table.insert(qcWorkingLog, "    NPC ZONE UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][3]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][3]) .. "'")
					qcWorkingDB[qcIndex][3][3] = qcEntry[3][3]
				end
				if (qcWorkingDB[qcIndex][3][4] ~= qcEntry[3][4]) then
					table.insert(qcWorkingLog, "    NPC X UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][4]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][4]) .. "'")
					qcWorkingDB[qcIndex][3][4] = qcEntry[3][4]
				end
				if (qcWorkingDB[qcIndex][3][5] ~= qcEntry[3][5]) then
					table.insert(qcWorkingLog, "    NPC Y UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][5]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][5]) .. "'")
					qcWorkingDB[qcIndex][3][5] = qcEntry[3][5]
				end
				if (qcWorkingDB[qcIndex][3][6] ~= qcEntry[3][6]) then
					table.insert(qcWorkingLog, "    MAP ID UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][6]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][6]) .. "'")
					qcWorkingDB[qcIndex][3][6] = qcEntry[3][6]
				end
				if (qcWorkingDB[qcIndex][3][7] ~= qcEntry[3][7]) then
					table.insert(qcWorkingLog, "    MAP LEVEL UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][7]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][7]) .. "'")
					qcWorkingDB[qcIndex][3][7] = qcEntry[3][7]
				end
				--[[ Map ignore will not be updated as it will overwrite any manually set values ]]--
			else -- [[ The quest category is known, which means the quest must have been accepted, therefore all information should be available ]]--
				--[[ If for some random reason the ID was not present, update it ]]--
				if (qcEntry[1][1] == nil) then qcEntry[1][1] = qcIndex end
				if (qcWorkingDB[qcIndex][1][2] ~= qcEntry[1][2]) then
					--[[ Do a check to see if the first character of the quest name is a square bracket. If it is, don't use the data as it will likely have a level tag on the front of it ]]--
					if (string.sub(tostring(qcEntry[1][2]), 1, 1) ~= "[") then
						table.insert(qcWorkingLog, "    NAME UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][1][2]) .. "' NEW VALUE: '" .. tostring(qcEntry[1][2]) .. "'")
						qcWorkingDB[qcIndex][1][2] = qcEntry[1][2]
					end
				end
				if (qcWorkingDB[qcIndex][1][3] ~= qcEntry[1][3]) then
					table.insert(qcWorkingLog, "    LEVEL UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][1][3]) .. "' NEW VALUE: '" .. tostring(qcEntry[1][3]) .. "'")
					qcWorkingDB[qcIndex][1][3] = qcEntry[1][3]
				end
				if (qcWorkingDB[qcIndex][1][4] ~= qcEntry[1][4]) then
					table.insert(qcWorkingLog, "    CATEGORY UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][1][4]) .. "' NEW VALUE: '" .. tostring(qcEntry[1][4]) .. "'")
					qcWorkingDB[qcIndex][1][4] = qcEntry[1][4]
				end
				--[[ Quest type will not be updated as it will overwrite any manually set types (eg. repeatables or specials) ]]--
				if (qcWorkingDB[qcIndex][2][1] ~= qcEntry[2][1]) then
					if (qcEntry[2][1] ~= 99999) then
						table.insert(qcWorkingLog, "    ZONE ID UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][2][1]) .. "' NEW VALUE: '" .. tostring(qcEntry[2][1]) .. "'")
						qcWorkingDB[qcIndex][1][4] = qcEntry[2][1]
					end
				end
				if (qcWorkingDB[qcIndex][3][1] ~= qcEntry[3][1]) then
					table.insert(qcWorkingLog, "    NPC ID UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][1]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][1]) .. "'")
					qcWorkingDB[qcIndex][3][1] = qcEntry[3][1]
				end
				if (qcWorkingDB[qcIndex][3][2] ~= qcEntry[3][2]) then
					table.insert(qcWorkingLog, "    NPC NAME UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][2]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][2]) .. "'")
					qcWorkingDB[qcIndex][3][2] = qcEntry[3][2]
				end
				if (qcWorkingDB[qcIndex][3][3] ~= qcEntry[3][3]) then
					table.insert(qcWorkingLog, "    NPC ZONE UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][3]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][3]) .. "'")
					qcWorkingDB[qcIndex][3][3] = qcEntry[3][3]
				end
				if (qcWorkingDB[qcIndex][3][4] ~= qcEntry[3][4]) then
					table.insert(qcWorkingLog, "    NPC X UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][4]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][4]) .. "'")
					qcWorkingDB[qcIndex][3][4] = qcEntry[3][4]
				end
				if (qcWorkingDB[qcIndex][3][5] ~= qcEntry[3][5]) then
					table.insert(qcWorkingLog, "    NPC Y UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][5]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][5]) .. "'")
					qcWorkingDB[qcIndex][3][5] = qcEntry[3][5]
				end
				if (qcWorkingDB[qcIndex][3][6] ~= qcEntry[3][6]) then
					table.insert(qcWorkingLog, "    MAP ID UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][6]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][6]) .. "'")
					qcWorkingDB[qcIndex][3][6] = qcEntry[3][6]
				end
				if (qcWorkingDB[qcIndex][3][7] ~= qcEntry[3][7]) then
					table.insert(qcWorkingLog, "    MAP LEVEL UPDATE - ORIGINAL VALUE: '" .. tostring(qcWorkingDB[qcIndex][3][7]) .. "' NEW VALUE: '" .. tostring(qcEntry[3][7]) .. "'")
					qcWorkingDB[qcIndex][3][7] = qcEntry[3][7]
				end
				--[[ Map ignore will not be updated as it will overwrite any manually set values ]]--
			end
		end
	end

	print(tostring(qcRecordCount) .. " quest records checked and updated. " .. tostring(qcNewCount) .. " brand new quests added.")

end

local function qcGetQuestCategory(qcQuestID)

local _S
local qcIsHeader
local qcHeader
local qcQuestIDIndex = GetQuestLogIndexByID(qcQuestID)

	if (qcQuestIDIndex == 0) then return nil end

	while (qcQuestIDIndex >= 1) do
		qcHeader, _S, _S, _S, qcIsHeader, _S, _S, _S, _S = GetQuestLogTitle(qcQuestIDIndex)
		if (qcIsHeader == 1) then return qcHeader end
		qcQuestIDIndex = qcQuestIDIndex - 1
	end

	return nil

end

function qcSetClassBits()

	local qcChangeCount = 0
	local qcRecordCount = 0
	table.insert(qcWorkingLog, "--------------------------")
	table.insert(qcWorkingLog, "PROCESSING CLASS QUESTS...")
	table.insert(qcWorkingLog, "--------------------------")

	for qcIndex, qcEntry in pairs(qcWorkingDB) do
		qcRecordCount = (qcRecordCount + 1)
		if (string.upper(qcEntry[1][4]) == "WARRIOR") then
			if (qcEntry[4][3] ~= 1) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 1
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR WARRIOR")
			end
		elseif (string.upper(qcEntry[1][4]) == "PALADIN") then
			if (qcEntry[4][3] ~= 2) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 2
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR PALADIN")
			end
		elseif (string.upper(qcEntry[1][4]) == "HUNTER") then
			if (qcEntry[4][3] ~= 4) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 4
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR HUNTER")
			end
		elseif (string.upper(qcEntry[1][4]) == "ROGUE") then
			if (qcEntry[4][3] ~= 8) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 8
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR ROGUE")
			end
		elseif (string.upper(qcEntry[1][4]) == "PRIEST") then
			if (qcEntry[4][3] ~= 16) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 16
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR PRIEST")
			end
		elseif (string.upper(qcEntry[1][4]) == "DEATHKNIGHT") then
			if (qcEntry[4][3] ~= 32) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 32
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR DEATHKNIGHT")
			end
		elseif (string.upper(qcEntry[1][4]) == "SHAMAN") then
			if (qcEntry[4][3] ~= 64) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 64
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR SHAMAN")
			end
		elseif (string.upper(qcEntry[1][4]) == "MAGE") then
			if (qcEntry[4][3] ~= 128) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 128
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR MAGE")
			end
		elseif (string.upper(qcEntry[1][4]) == "WARLOCK") then
			if (qcEntry[4][3] ~= 256) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 256
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR WARLOCK")
			end
		elseif (string.upper(qcEntry[1][4]) == "DRUID") then
			if (qcEntry[4][3] ~= 512) then
				qcChangeCount = (qcChangeCount + 1)
				qcEntry[4][3] = 512
				table.insert(qcWorkingLog, "CLASS QUEST UPDATE: " .. tostring(qcEntry[1][2]) .. " HAS BEEN FLAGGED FOR DRUID")
			end
		end
	end

	print(tostring(qcRecordCount) .. " records checked against class categories and updated. " .. tostring(qcChangeCount) .. " changes were made.")

end

local function qcRound(num, idp)

	return tonumber(string.format("%." .. (idp or 0) .. "f", num))

end

function qcCollectOnProgress()
if (GetLocale() == "enUS") or (GetLocale() == "enGB") then

	local qcQuestID = GetQuestID()
	if (qcQuestID == 0) or (qcQuestID == nil) then return nil end

	if (qcCollected[qcQuestID] ~= nil) then
		--print("QUEST_PROGRESS: Quest already exists in DB. Not likely to be repeatable or seasonal.")
		return nil
	else
		--print("QUEST_PROGRESS: Quest does not already exist in DB meaning it is likely to be repeatable, seasonal, or a quest that was in the players log before installing the addon.")
		--[[ TODO: Upon addon's first load, check quest log to record (or create blank records) for all quests ]]--

		local qcQuestName = GetTitleText()

		if (QuestIsDaily()) then return nil end --[[ Can't be flagged repeatable if daily ]]--
		if (QuestIsWeekly()) then return nil end --[[ Can't be flagged repeatable if weekly ]]--

		local qcNPCID = 0
		local qcNPCName = UnitName("questnpc")
		if (UnitExists("questnpc")) then
			if (qcNPCName == UnitName("player")) then
				qcNPCName = "<Remote Quest Offer>"
			else
				qcNPCID = tonumber(strsub(UnitGUID("questnpc"), 7, 10), 16)
			end
		end

		local qcNPCZone = GetRealZoneText()

		local qcNPCX = 0
		local qcNPCY = 0
		do
			local qcX, qcY = GetPlayerMapPosition("player")
			if (qcX > 0) and (qcY > 0) then
				qcNPCX = qcRound(qcX*100, 2)
				qcNPCY = qcRound(qcY*100, 2)
			end
		end

		--[[ TODO: Possible use of GetQuestWorldMapAreaID? ]]--
		local qcMapID = 0
		local qcMapLevel = 0
		do
			SetMapToCurrentZone()
			if (GetCurrentMapAreaID() > 0) then
				qcMapID = GetCurrentMapAreaID()
			end
			if (GetCurrentMapDungeonLevel() > 0) then
				qcMapLevel = GetCurrentMapDungeonLevel()
			end
		end

		local qcFaction = 0
		do
			local qcEFaction, _S = UnitFactionGroup("player")
			qcFaction = qcFactionBits[string.upper(qcEFaction)]
		end

		local qcRace = 0
		do
			local _S, qcERace = UnitRace("player")
			qcRace = qcRaceBits[string.upper(qcERace)]
		end

		local qcClass = 0
		do
			local _S, qcEClass = UnitClass("player")
			qcClass = qcClassBits[string.upper(qcEClass)]
		end

		if (qcRepeatables[qcQuestID] == nil) then
			qcRepeatables[qcQuestID] = {}
			qcRepeatables[qcQuestID][1] = {}
			qcRepeatables[qcQuestID][3] = {}
			qcRepeatables[qcQuestID][4] = {}
			qcRepeatables[qcQuestID][1][1] = qcQuestID
			qcRepeatables[qcQuestID][1][2] = qcQuestName
			qcRepeatables[qcQuestID][3][1] = qcNPCID
			qcRepeatables[qcQuestID][3][2] = qcNPCName
			qcRepeatables[qcQuestID][3][3] = qcNPCZone
			qcRepeatables[qcQuestID][3][4] = qcNPCX
			qcRepeatables[qcQuestID][3][5] = qcNPCY
			qcRepeatables[qcQuestID][3][6] = qcMapID
			qcRepeatables[qcQuestID][3][7] = qcMapLevel
			qcRepeatables[qcQuestID][4][1] = qcFaction
			qcRepeatables[qcQuestID][4][2] = qcRace
			qcRepeatables[qcQuestID][4][3] = qcClass
		else
			if (qcRepeatables[qcQuestID][1] == nil) then qcRepeatables[qcQuestID][1] = {} end
			if (qcRepeatables[qcQuestID][3] == nil) then qcRepeatables[qcQuestID][3] = {} end
			if (qcRepeatables[qcQuestID][4] == nil) then qcRepeatables[qcQuestID][4] = {} end
			qcRepeatables[qcQuestID][1][1] = qcQuestID
			qcRepeatables[qcQuestID][1][2] = qcQuestName
			qcRepeatables[qcQuestID][3][1] = qcNPCID
			qcRepeatables[qcQuestID][3][2] = qcNPCName
			qcRepeatables[qcQuestID][3][3] = qcNPCZone
			qcRepeatables[qcQuestID][3][4] = qcNPCX
			qcRepeatables[qcQuestID][3][5] = qcNPCY
			qcRepeatables[qcQuestID][3][6] = qcMapID
			qcRepeatables[qcQuestID][3][7] = qcMapLevel
			if (bit.band(qcRepeatables[qcQuestID][4][1], qcFaction) == 0) then
				qcRepeatables[qcQuestID][4][1] = tonumber(qcRepeatables[qcQuestID][4][1] + qcFaction)
			end
			if (bit.band(qcRepeatables[qcQuestID][4][2], qcRace) == 0) then
				qcRepeatables[qcQuestID][4][2] = tonumber(qcRepeatables[qcQuestID][4][2] + qcRace)
			end
			if (bit.band(qcRepeatables[qcQuestID][4][3], qcClass) == 0) then
				qcRepeatables[qcQuestID][4][3] = tonumber(qcRepeatables[qcQuestID][4][3] + qcClass)
			end
		end
	end

end
end

function qcCollectOnDetail()
if (GetLocale() == "enUS") or (GetLocale() == "enGB") then

	local qcQuestID = GetQuestID()
	if (qcQuestID == 0) or (qcQuestID == nil) then return nil end

	local qcQuestName = GetTitleText()
	local qcQuestLevel = 0
	--[[ ON ACCEPT
	do
		local _S, qcN, qcL, qcT
		qcN, qcL, qcT, _S, _S, _S, _S, _S, _S = GetQuestLogTitle(GetQuestLogIndexByID(qcQuestID))
		if (qcT == nil) then qcQuestName = tostring(qcN) else qcQuestName = tostring(qcN .. " [" .. qcT .. "]") end
		if (qcL > 0) then qcQuestLevel = qcL end
	end
	]]--

	--[[ ON ACCEPT
	local qcCategory = (qcGetQuestCategory(qcQuestID) or "<Category Unknown>")
	--]]
	local qcCategory = "<Category Unknown>"

	local qcQuestType = 1
	if (QuestIsDaily()) then
		qcQuestType = 3
	elseif (QuestIsWeekly()) then
		qcQuestType = 5
	end

	local qcZoneID = 99999
	--[[ ON ACCEPT
	for qcIndex, qcEntry in ipairs(qcQuestCategories) do
		if (qcEntry[2] == qcCategory) then
			qcZoneID = qcEntry[1]
			break
		end
	end
	--]]

	local qcNPCID = 0
	local qcNPCName = UnitName("questnpc")
	if (UnitExists("questnpc")) then
		if (qcNPCName == UnitName("player")) then
			qcNPCName = "<Remote Quest Offer>"
		else
			qcNPCID = tonumber(strsub(UnitGUID("questnpc"), 7, 10), 16)
		end
	end

	local qcNPCZone = GetRealZoneText()

	local qcNPCX = 0
	local qcNPCY = 0
	do
		local qcX, qcY = GetPlayerMapPosition("player")
		if (qcX > 0) and (qcY > 0) then
			qcNPCX = qcRound(qcX*100, 2)
			qcNPCY = qcRound(qcY*100, 2)
		end
	end

	--[[ TODO: Possible use of GetQuestWorldMapAreaID? ]]--
	local qcMapID = 0
	local qcMapLevel = 0
	do
		SetMapToCurrentZone()
		if (GetCurrentMapAreaID() > 0) then
			qcMapID = GetCurrentMapAreaID()
		end
		if (GetCurrentMapDungeonLevel() > 0) then
			qcMapLevel = GetCurrentMapDungeonLevel()
		end
	end

	local qcMapIgnore = 0

	local qcFaction = 0
	do
		local qcEFaction, _S = UnitFactionGroup("player")
		qcFaction = qcFactionBits[string.upper(qcEFaction)]
	end

	local qcRace = 0
	do
		local _S, qcERace = UnitRace("player")
		qcRace = qcRaceBits[string.upper(qcERace)]
	end

	local qcClass = 0
	do
		local _S, qcEClass = UnitClass("player")
		qcClass = qcClassBits[string.upper(qcEClass)]
	end

	local qcQuestNotes = nil

	if (qcCollected[qcQuestID] == nil) then
		qcCollected[qcQuestID] = {}
		qcCollected[qcQuestID][1] = {}
		qcCollected[qcQuestID][2] = {}
		qcCollected[qcQuestID][3] = {}
		qcCollected[qcQuestID][4] = {}
		qcCollected[qcQuestID][5] = {}
		qcCollected[qcQuestID][1][1] = qcQuestID
		qcCollected[qcQuestID][1][2] = qcQuestName
		qcCollected[qcQuestID][1][3] = qcQuestLevel
		qcCollected[qcQuestID][1][4] = qcCategory
		qcCollected[qcQuestID][1][5] = qcQuestType
		qcCollected[qcQuestID][2][1] = qcZoneID
		qcCollected[qcQuestID][3][1] = qcNPCID
		qcCollected[qcQuestID][3][2] = qcNPCName
		qcCollected[qcQuestID][3][3] = qcNPCZone
		qcCollected[qcQuestID][3][4] = qcNPCX
		qcCollected[qcQuestID][3][5] = qcNPCY
		qcCollected[qcQuestID][3][6] = qcMapID
		qcCollected[qcQuestID][3][7] = qcMapLevel
		qcCollected[qcQuestID][3][8] = qcMapIgnore
		qcCollected[qcQuestID][4][1] = qcFaction
		qcCollected[qcQuestID][4][2] = qcRace
		qcCollected[qcQuestID][4][3] = qcClass
		qcCollected[qcQuestID][5][1] = qcQuestNotes
	else
		if (qcCollected[qcQuestID][1] == nil) then qcCollected[qcQuestID][1] = {} end
		if (qcCollected[qcQuestID][2] == nil) then qcCollected[qcQuestID][2] = {} end
		if (qcCollected[qcQuestID][3] == nil) then qcCollected[qcQuestID][3] = {} end
		if (qcCollected[qcQuestID][4] == nil) then qcCollected[qcQuestID][4] = {} end
		if (qcCollected[qcQuestID][5] == nil) then qcCollected[qcQuestID][5] = {} end
		qcCollected[qcQuestID][1][1] = qcQuestID
		qcCollected[qcQuestID][1][2] = qcQuestName
		qcCollected[qcQuestID][1][3] = qcQuestLevel
		qcCollected[qcQuestID][1][4] = qcCategory
		qcCollected[qcQuestID][1][5] = qcQuestType
		qcCollected[qcQuestID][2][1] = qcZoneID
		qcCollected[qcQuestID][3][1] = qcNPCID
		qcCollected[qcQuestID][3][2] = qcNPCName
		qcCollected[qcQuestID][3][3] = qcNPCZone
		qcCollected[qcQuestID][3][4] = qcNPCX
		qcCollected[qcQuestID][3][5] = qcNPCY
		qcCollected[qcQuestID][3][6] = qcMapID
		qcCollected[qcQuestID][3][7] = qcMapLevel
		qcCollected[qcQuestID][3][8] = qcMapIgnore
		if (bit.band(qcCollected[qcQuestID][4][1], qcFaction) == 0) then
			qcCollected[qcQuestID][4][1] = tonumber(qcCollected[qcQuestID][4][1] + qcFaction)
		end
		if (bit.band(qcCollected[qcQuestID][4][2], qcRace) == 0) then
			qcCollected[qcQuestID][4][2] = tonumber(qcCollected[qcQuestID][4][2] + qcRace)
		end
		if (bit.band(qcCollected[qcQuestID][4][3], qcClass) == 0) then
			qcCollected[qcQuestID][4][3] = tonumber(qcCollected[qcQuestID][4][3] + qcClass)
		end
		qcCollected[qcQuestID][5][1] = qcQuestNotes
	end

	--[[ Show quest ID on the quest detail frame ]]--
	local qcNPCNameText = QuestFrameNpcNameText:GetText()
	QuestFrameNpcNameText:SetText(qcNPCNameText .. " [" .. tostring(qcQuestID) .. "]")

end
end

function qcCollectOnAccept(...)
if (GetLocale() == "enUS") or (GetLocale() == "enGB") then

	local qcQuestLogIndex, qcQuestID = ... --[[ Passed on through QUEST_ACCEPT event ]]--
	if (qcQuestID == 0) or (qcQuestID == nil) then return nil end

	local qcQuestName --[[ Collected via quest log with any tags attached ]]--
	local qcQuestLevel = 0
	do
		local _S, qcN, qcL, qcT
		qcN, qcL, qcT, _S, _S, _S, _S, _S, _S = GetQuestLogTitle(qcQuestLogIndex)
		if (qcT == nil) then qcQuestName = tostring(qcN) else qcQuestName = tostring(qcN .. " [" .. qcT .. "]") end
		if (qcL > 0) then qcQuestLevel = qcL end
	end

	local qcCategory = (qcGetQuestCategory(qcQuestID) or "<Category Unknown>")

	local qcQuestType = 1
	if (QuestIsDaily()) then
		qcQuestType = 3
	elseif (QuestIsWeekly()) then
		qcQuestType = 5
	end

	local qcZoneID = 99999
	for qcIndex, qcEntry in ipairs(qcQuestCategories) do
		if (qcEntry[2] == qcCategory) then
			qcZoneID = qcEntry[1]
			break
		end
	end

	--[[ ON DETAIL
	local qcNPCID = 0
	local qcNPCName = UnitName("questnpc")
	if (UnitExists("questnpc")) then
		if (qcNPCName == UnitName("player")) then
			qcNPCName = "<Remote Quest Offer>"
		else
			qcNPCID = tonumber(strsub(UnitGUID("questnpc"), 7, 10), 16)
		end
	end
	--]]

	local qcNPCZone = GetRealZoneText()

	local qcNPCX = 0
	local qcNPCY = 0
	do
		local qcX, qcY = GetPlayerMapPosition("player")
		if (qcX > 0) and (qcY > 0) then
			qcNPCX = qcRound(qcX*100, 2)
			qcNPCY = qcRound(qcY*100, 2)
		end
	end

	--[[ TODO: Possible use of GetQuestWorldMapAreaID? ]]--
	local qcMapID = 0
	local qcMapLevel = 0
	do
		SetMapToCurrentZone()
		if (GetCurrentMapAreaID() > 0) then
			qcMapID = GetCurrentMapAreaID()
		end
		if (GetCurrentMapDungeonLevel() > 0) then
			qcMapLevel = GetCurrentMapDungeonLevel()
		end
	end

	local qcMapIgnore = 0

	local qcFaction = 0
	do
		local qcEFaction, _S = UnitFactionGroup("player")
		qcFaction = qcFactionBits[string.upper(qcEFaction)]
	end

	local qcRace = 0
	do
		local _S, qcERace = UnitRace("player")
		qcRace = qcRaceBits[string.upper(qcERace)]
	end

	local qcClass = 0
	do
		local _S, qcEClass = UnitClass("player")
		qcClass = qcClassBits[string.upper(qcEClass)]
	end

	local qcQuestNotes = nil

	if (qcCollected[qcQuestID] == nil) then
		qcCollected[qcQuestID] = {}
		qcCollected[qcQuestID][1] = {}
		qcCollected[qcQuestID][2] = {}
		qcCollected[qcQuestID][3] = {}
		qcCollected[qcQuestID][4] = {}
		qcCollected[qcQuestID][5] = {}
		qcCollected[qcQuestID][1][1] = qcQuestID
		qcCollected[qcQuestID][1][2] = qcQuestName
		qcCollected[qcQuestID][1][3] = qcQuestLevel
		qcCollected[qcQuestID][1][4] = qcCategory
		qcCollected[qcQuestID][1][5] = qcQuestType
		qcCollected[qcQuestID][2][1] = qcZoneID
		--qcCollected[qcQuestID][3][1] = qcNPCID --[[ ON DETAIL ]]--
		--qcCollected[qcQuestID][3][2] = qcNPCName --[[ ON DETAIL ]]--
		qcCollected[qcQuestID][3][3] = qcNPCZone
		qcCollected[qcQuestID][3][4] = qcNPCX
		qcCollected[qcQuestID][3][5] = qcNPCY
		qcCollected[qcQuestID][3][6] = qcMapID
		qcCollected[qcQuestID][3][7] = qcMapLevel
		qcCollected[qcQuestID][3][8] = qcMapIgnore
		qcCollected[qcQuestID][4][1] = qcFaction
		qcCollected[qcQuestID][4][2] = qcRace
		qcCollected[qcQuestID][4][3] = qcClass
		qcCollected[qcQuestID][5][1] = qcQuestNotes
	else
		if (qcCollected[qcQuestID][1] == nil) then qcCollected[qcQuestID][1] = {} end
		if (qcCollected[qcQuestID][2] == nil) then qcCollected[qcQuestID][2] = {} end
		if (qcCollected[qcQuestID][3] == nil) then qcCollected[qcQuestID][3] = {} end
		if (qcCollected[qcQuestID][4] == nil) then qcCollected[qcQuestID][4] = {} end
		if (qcCollected[qcQuestID][5] == nil) then qcCollected[qcQuestID][5] = {} end
		qcCollected[qcQuestID][1][1] = qcQuestID
		qcCollected[qcQuestID][1][2] = qcQuestName
		qcCollected[qcQuestID][1][3] = qcQuestLevel
		qcCollected[qcQuestID][1][4] = qcCategory
		qcCollected[qcQuestID][1][5] = qcQuestType
		qcCollected[qcQuestID][2][1] = qcZoneID
		--qcCollected[qcQuestID][3][1] = qcNPCID --[[ ON DETAIL ]]--
		--qcCollected[qcQuestID][3][2] = qcNPCName --[[ ON DETAIL ]]--
		qcCollected[qcQuestID][3][3] = qcNPCZone
		qcCollected[qcQuestID][3][4] = qcNPCX
		qcCollected[qcQuestID][3][5] = qcNPCY
		qcCollected[qcQuestID][3][6] = qcMapID
		qcCollected[qcQuestID][3][7] = qcMapLevel
		qcCollected[qcQuestID][3][8] = qcMapIgnore
		if (bit.band(qcCollected[qcQuestID][4][1], qcFaction) == 0) then
			qcCollected[qcQuestID][4][1] = tonumber(qcCollected[qcQuestID][4][1] + qcFaction)
		end
		if (bit.band(qcCollected[qcQuestID][4][2], qcRace) == 0) then
			qcCollected[qcQuestID][4][2] = tonumber(qcCollected[qcQuestID][4][2] + qcRace)
		end
		if (bit.band(qcCollected[qcQuestID][4][3], qcClass) == 0) then
			qcCollected[qcQuestID][4][3] = tonumber(qcCollected[qcQuestID][4][3] + qcClass)
		end
		qcCollected[qcQuestID][5][1] = qcQuestNotes
	end

end
end

qcSVData = {
	[353] = {
		{
			353, -- [1]
			"Stormpike's Delivery", -- [2]
			15, -- [3]
			"Stormwind City", -- [4]
			1, -- [5]
		}, -- [1]
		{
			55, -- [1]
		}, -- [2]
		{
			1416, -- [1]
			"Grimand Elmore", -- [2]
			"Stormwind City", -- [3]
			59.73, -- [4]
			33.78, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26271] = {
		{
			26271, -- [1]
			"Feeding the Hungry and the Hopeless", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42575, -- [1]
			"Hope Saldean", -- [2]
			"Westfall", -- [3]
			56.97, -- [4]
			47.1, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[123] = {
		{
			123, -- [1]
			"The Collector", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Gold Pickup Schedule", -- [2]
			"Elwynn Forest", -- [3]
			78.61, -- [4]
			67.16, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26150] = {
		{
			26150, -- [1]
			"A Visit With Maybell", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			253, -- [1]
			"William Pestle", -- [2]
			"Elwynn Forest", -- [3]
			43.32, -- [4]
			65.70999999999999, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26152] = {
		{
			26152, -- [1]
			"Wanted: James Clark", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Bounty Board", -- [2]
			"Elwynn Forest", -- [3]
			74.01000000000001, -- [4]
			72.31999999999999, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26287] = {
		{
			26287, -- [1]
			"The Westfall Brigade", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			821, -- [1]
			"Captain Danuvin", -- [2]
			"Westfall", -- [3]
			56.46, -- [4]
			47.57, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26289] = {
		{
			26289, -- [1]
			"Find Agent Kearnen", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			234, -- [1]
			"Marshal Gryan Stoutmantle", -- [2]
			"Westfall", -- [3]
			56.32, -- [4]
			47.52, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26291] = {
		{
			26291, -- [1]
			"Big Trouble in Moonbrook", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			7024, -- [1]
			"Agent Kearnen", -- [2]
			"Westfall", -- [3]
			68.33, -- [4]
			70.36, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[35] = {
		{
			35, -- [1]
			"Further Concerns", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			240, -- [1]
			"Marshal Dughan", -- [2]
			"Elwynn Forest", -- [3]
			42.11, -- [4]
			65.93000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[28708] = {
		{
			28708, -- [1]
			"Hero's Call: Outland!", -- [2]
			60, -- [3]
			"Hellfire Peninsula", -- [4]
			1, -- [5]
		}, -- [1]
		{
			70, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Hero's Call Board", -- [2]
			"Stormwind City", -- [3]
			62.91, -- [4]
			71.54000000000001, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26297] = {
		{
			26297, -- [1]
			"The Dawning of a New Day", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42425, -- [1]
			"Captain Alpert", -- [2]
			"Westfall", -- [3]
			42.11, -- [4]
			64.13, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[37] = {
		{
			37, -- [1]
			"Find the Lost Guards", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			261, -- [1]
			"Guard Thomas", -- [2]
			"Elwynn Forest", -- [3]
			73.97, -- [4]
			72.19, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[1097] = {
		{
			1097, -- [1]
			"Elmore's Task", -- [2]
			15, -- [3]
			"Stormwind City", -- [4]
			1, -- [5]
		}, -- [1]
		{
			55, -- [1]
		}, -- [2]
		{
			514, -- [1]
			"Smith Argus", -- [2]
			"Elwynn Forest", -- [3]
			41.71, -- [4]
			65.55, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26319] = {
		{
			26319, -- [1]
			"Secrets Revealed", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42425, -- [1]
			"Captain Alpert", -- [2]
			"Westfall", -- [3]
			42.11, -- [4]
			64.12000000000001, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[334] = {
		{
			334, -- [1]
			"Package for Thurman", -- [2]
			2, -- [3]
			"Stormwind City", -- [4]
			1, -- [5]
		}, -- [1]
		{
			55, -- [1]
		}, -- [2]
		{
			1428, -- [1]
			"Rema Schneider", -- [2]
			"Stormwind City", -- [3]
			58.09, -- [4]
			67.48, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[11] = {
		{
			11, -- [1]
			"Riverpaw Gnoll Bounty", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			963, -- [1]
			"Deputy Rainer", -- [2]
			"Elwynn Forest", -- [3]
			24.23, -- [4]
			74.45, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[176] = {
		{
			176, -- [1]
			"Wanted:  \"Hogger\" [Group]", -- [2]
			11, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Wanted Poster", -- [2]
			"Elwynn Forest", -- [3]
			24.55, -- [4]
			74.67, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[45] = {
		{
			45, -- [1]
			"Discover Rolf's Fate", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"A half-eaten body", -- [2]
			"Elwynn Forest", -- [3]
			72.66, -- [4]
			60.33, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[46] = {
		{
			46, -- [1]
			"Bounty on Murlocs", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Bounty Board", -- [2]
			"Elwynn Forest", -- [3]
			74.01000000000001, -- [4]
			72.31999999999999, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[184] = {
		{
			184, -- [1]
			"Furlbrow's Deed", -- [2]
			10, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Westfall Deed", -- [2]
			"Elwynn Forest", -- [3]
			24.78, -- [4]
			95.26000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26214] = {
		{
			26214, -- [1]
			"Hot On the Trail: Murlocs", -- [2]
			11, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42308, -- [1]
			"Lieutenant Horatio Laine", -- [2]
			"Westfall", -- [3]
			60.05, -- [4]
			19.28, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26347] = {
		{
			26347, -- [1]
			"Keeper of the Flame", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			392, -- [1]
			"Captain Grayson", -- [2]
			"Westfall", -- [3]
			30.5, -- [4]
			85.62000000000001, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26349] = {
		{
			26349, -- [1]
			"The Coastal Menace", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			392, -- [1]
			"Captain Grayson", -- [2]
			"Westfall", -- [3]
			30.5, -- [4]
			85.62000000000001, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26353] = {
		{
			26353, -- [1]
			"Captain Sanders' Hidden Treasure", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Captain Sanders' Treasure Map", -- [2]
			"Westfall", -- [3]
			54.86, -- [4]
			10.13, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26228] = {
		{
			26228, -- [1]
			"Livin' the Life", -- [2]
			11, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42405, -- [1]
			"Two-Shoed Lou", -- [2]
			"Westfall", -- [3]
			49.66, -- [4]
			19.39, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26230] = {
		{
			26230, -- [1]
			"Feast or Famine", -- [2]
			12, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42497, -- [1]
			"Mama Celeste", -- [2]
			"Westfall", -- [3]
			49.54, -- [4]
			19.14, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26232] = {
		{
			26232, -- [1]
			"Lou's Parting Thoughts", -- [2]
			12, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42405, -- [1]
			"Two-Shoed Lou", -- [2]
			"Westfall", -- [3]
			49.66, -- [4]
			19.39, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[52] = {
		{
			52, -- [1]
			"Protect the Frontier", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			261, -- [1]
			"Guard Thomas", -- [2]
			"Elwynn Forest", -- [3]
			73.97, -- [4]
			72.19, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26236] = {
		{
			26236, -- [1]
			"Shakedown at the Saldean's", -- [2]
			12, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42558, -- [1]
			"Lieutenant Horatio Laine", -- [2]
			"Westfall", -- [3]
			49.73, -- [4]
			19.51, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26365] = {
		{
			26365, -- [1]
			"Hero's Call: Redridge Mountains!", -- [2]
			15, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			821, -- [1]
			"Captain Danuvin", -- [2]
			"Westfall", -- [3]
			56.46, -- [4]
			47.57, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[5545] = {
		{
			5545, -- [1]
			"A Bundle of Trouble", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			10616, -- [1]
			"Supervisor Raelen", -- [2]
			"Elwynn Forest", -- [3]
			81.38, -- [4]
			66.11, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26371] = {
		{
			26371, -- [1]
			"The Legend of Captain Grayson", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			878, -- [1]
			"Scout Galiaan", -- [2]
			"Westfall", -- [3]
			56.39, -- [4]
			47.35, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26504] = {
		{
			26504, -- [1]
			"Wanted: Redridge Gnolls", -- [2]
			15, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Wanted!", -- [2]
			"Redridge Mountains", -- [3]
			16.05, -- [4]
			64.61, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26252] = {
		{
			26252, -- [1]
			"Heart of the Watcher", -- [2]
			12, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Harvest Watcher Heart", -- [2]
			"Westfall", -- [3]
			54.47, -- [4]
			32.83, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26508] = {
		{
			26508, -- [1]
			"Nida's Necklace", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			8965, -- [1]
			"Shawn", -- [2]
			"Redridge Mountains", -- [3]
			28.35, -- [4]
			48.85, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26510] = {
		{
			26510, -- [1]
			"We Must Prepare!", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			344, -- [1]
			"Magistrate Solomon", -- [2]
			"Redridge Mountains", -- [3]
			28.91, -- [4]
			41.11, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26512] = {
		{
			26512, -- [1]
			"Tuning the Gnomecorder", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			344, -- [1]
			"Magistrate Solomon", -- [2]
			"Redridge Mountains", -- [3]
			28.91, -- [4]
			41.12, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26514] = {
		{
			26514, -- [1]
			"Canyon Romp", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"<Remote Quest Offer>", -- [2]
			"Redridge Mountains", -- [3]
			32.29, -- [4]
			39.49, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[59] = {
		{
			59, -- [1]
			"Cloth and Leather Armor", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			261, -- [1]
			"Guard Thomas", -- [2]
			"Elwynn Forest", -- [3]
			73.97, -- [4]
			72.18000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26266] = {
		{
			26266, -- [1]
			"Hope for the People", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			235, -- [1]
			"Salma Saldean", -- [2]
			"Westfall", -- [3]
			56.42, -- [4]
			30.52, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26270] = {
		{
			26270, -- [1]
			"You Have Our Thanks", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			233, -- [1]
			"Farmer Saldean", -- [2]
			"Westfall", -- [3]
			56.04, -- [4]
			31.23, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26286] = {
		{
			26286, -- [1]
			"In Defense of Westfall", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			234, -- [1]
			"Marshal Gryan Stoutmantle", -- [2]
			"Westfall", -- [3]
			56.33, -- [4]
			47.52, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26288] = {
		{
			26288, -- [1]
			"Jango Spothide", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			821, -- [1]
			"Captain Danuvin", -- [2]
			"Westfall", -- [3]
			56.46, -- [4]
			47.57, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26290] = {
		{
			26290, -- [1]
			"Secrets of the Tower", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			7024, -- [1]
			"Agent Kearnen", -- [2]
			"Westfall", -- [3]
			68.33, -- [4]
			70.37000000000001, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26292] = {
		{
			26292, -- [1]
			"To Moonbrook!", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			234, -- [1]
			"Marshal Gryan Stoutmantle", -- [2]
			"Westfall", -- [3]
			56.32, -- [4]
			47.52, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[71] = {
		{
			71, -- [1]
			"Report to Thomas", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Rolf's corpse", -- [2]
			"Elwynn Forest", -- [3]
			79.79000000000001, -- [4]
			55.52, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[147] = {
		{
			147, -- [1]
			"Manhunt", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			42256, -- [1]
			"Marshal McCree", -- [2]
			"Elwynn Forest", -- [3]
			81.86, -- [4]
			66.04000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[76] = {
		{
			76, -- [1]
			"The Jasperlode Mine", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			240, -- [1]
			"Marshal Dughan", -- [2]
			"Elwynn Forest", -- [3]
			42.11, -- [4]
			65.93000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26728] = {
		{
			26728, -- [1]
			"Hero's Call: Duskwood!", -- [2]
			20, -- [3]
			"Duskwood", -- [4]
			1, -- [5]
		}, -- [1]
		{
			37, -- [1]
		}, -- [2]
		{
			900, -- [1]
			"Bailiff Conacher", -- [2]
			"Redridge Mountains", -- [3]
			28.68, -- [4]
			40.96, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[83] = {
		{
			83, -- [1]
			"Fine Linen Goods", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			278, -- [1]
			"Sara Timberlain", -- [2]
			"Elwynn Forest", -- [3]
			79.45999999999999, -- [4]
			68.70999999999999, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[332] = {
		{
			332, -- [1]
			"Wine Shop Advert", -- [2]
			2, -- [3]
			"Stormwind City", -- [4]
			1, -- [5]
		}, -- [1]
		{
			55, -- [1]
		}, -- [2]
		{
			1432, -- [1]
			"Renato Gallina", -- [2]
			"Stormwind City", -- [3]
			63.77, -- [4]
			73.59, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[85] = {
		{
			85, -- [1]
			"Lost Necklace", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			246, -- [1]
			"\"Auntie\" Bernice Stonefield", -- [2]
			"Elwynn Forest", -- [3]
			34.49, -- [4]
			84.26000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[86] = {
		{
			86, -- [1]
			"Pie for Billy", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			247, -- [1]
			"Billy Maclure", -- [2]
			"Elwynn Forest", -- [3]
			43.13, -- [4]
			85.72, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[87] = {
		{
			87, -- [1]
			"Goldtooth", -- [2]
			8, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			247, -- [1]
			"Billy Maclure", -- [2]
			"Elwynn Forest", -- [3]
			43.13, -- [4]
			85.72, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[88] = {
		{
			88, -- [1]
			"Princess Must Die!", -- [2]
			9, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			244, -- [1]
			"Ma Stonefield", -- [2]
			"Elwynn Forest", -- [3]
			34.66, -- [4]
			84.48, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26295] = {
		{
			26295, -- [1]
			"Propaganda", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42425, -- [1]
			"Captain Alpert", -- [2]
			"Westfall", -- [3]
			42.1, -- [4]
			64.11, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26322] = {
		{
			26322, -- [1]
			"Rise of the Brotherhood", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			234, -- [1]
			"Marshal Gryan Stoutmantle", -- [2]
			"Westfall", -- [3]
			56.33, -- [4]
			47.52, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26209] = {
		{
			26209, -- [1]
			"Murder Was The Case That They Gave Me", -- [2]
			11, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42308, -- [1]
			"Lieutenant Horatio Laine", -- [2]
			"Westfall", -- [3]
			60.05, -- [4]
			19.29, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[84] = {
		{
			84, -- [1]
			"Back to Billy", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			246, -- [1]
			"\"Auntie\" Bernice Stonefield", -- [2]
			"Elwynn Forest", -- [3]
			34.48, -- [4]
			84.26000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26213] = {
		{
			26213, -- [1]
			"Hot On the Trail: The Riverpaw Clan", -- [2]
			10, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42308, -- [1]
			"Lieutenant Horatio Laine", -- [2]
			"Westfall", -- [3]
			60.05, -- [4]
			19.28, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26215] = {
		{
			26215, -- [1]
			"Meet Two-Shoed Lou", -- [2]
			11, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42308, -- [1]
			"Lieutenant Horatio Laine", -- [2]
			"Westfall", -- [3]
			60.05, -- [4]
			19.28, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26296] = {
		{
			26296, -- [1]
			"Evidence Collection", -- [2]
			14, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Red Bandana", -- [2]
			"Westfall", -- [3]
			41.48, -- [4]
			67.18000000000001, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[333] = {
		{
			333, -- [1]
			"Harlan Needs a Resupply", -- [2]
			2, -- [3]
			"Stormwind City", -- [4]
			1, -- [5]
		}, -- [1]
		{
			55, -- [1]
		}, -- [2]
		{
			1427, -- [1]
			"Harlan Bagley", -- [2]
			"Stormwind City", -- [3]
			62.31, -- [4]
			67.94, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26348] = {
		{
			26348, -- [1]
			"The Coast Isn't Clear", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			392, -- [1]
			"Captain Grayson", -- [2]
			"Westfall", -- [3]
			30.5, -- [4]
			85.62000000000001, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26511] = {
		{
			26511, -- [1]
			"Lake Everstill Clean Up", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			900, -- [1]
			"Bailiff Conacher", -- [2]
			"Redridge Mountains", -- [3]
			28.68, -- [4]
			40.96, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26509] = {
		{
			26509, -- [1]
			"An Unwelcome Guest", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			342, -- [1]
			"Martie Jainrose", -- [2]
			"Redridge Mountains", -- [3]
			22.04, -- [4]
			42.69, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26354] = {
		{
			26354, -- [1]
			"Captain Sanders' Hidden Treasure", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Captain's Footlocker", -- [2]
			"Westfall", -- [3]
			25.9, -- [4]
			47.76, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26229] = {
		{
			26229, -- [1]
			"\"I TAKE Candle!\"", -- [2]
			11, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42498, -- [1]
			"Jimb \"Candles\" McHannigan", -- [2]
			"Westfall", -- [3]
			49.59, -- [4]
			19.6, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26356] = {
		{
			26356, -- [1]
			"Captain Sanders' Hidden Treasure", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Old Jug", -- [2]
			"Westfall", -- [3]
			40.63, -- [4]
			17.02, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26378] = {
		{
			26378, -- [1]
			"Hero's Call: Westfall!", -- [2]
			10, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			240, -- [1]
			"Marshal Dughan", -- [2]
			"Elwynn Forest", -- [3]
			42.11, -- [4]
			65.93000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[111] = {
		{
			111, -- [1]
			"Speak with Gramma", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			252, -- [1]
			"Tommy Joe Stonefield", -- [2]
			"Elwynn Forest", -- [3]
			29.84, -- [4]
			86, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26237] = {
		{
			26237, -- [1]
			"Times are Tough", -- [2]
			12, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			233, -- [1]
			"Farmer Saldean", -- [2]
			"Westfall", -- [3]
			56.04, -- [4]
			31.23, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[106] = {
		{
			106, -- [1]
			"Young Lovers", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			251, -- [1]
			"Maybell Maclure", -- [2]
			"Elwynn Forest", -- [3]
			43.15, -- [4]
			89.62000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26241] = {
		{
			26241, -- [1]
			"Westfall Stew", -- [2]
			12, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			235, -- [1]
			"Salma Saldean", -- [2]
			"Westfall", -- [3]
			56.42, -- [4]
			30.52, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26370] = {
		{
			26370, -- [1]
			"Return to Sentinel Hill", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			29611, -- [1]
			"King Varian Wrynn", -- [2]
			"Stormwind City", -- [3]
			85.78, -- [4]
			31.72, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[112] = {
		{
			112, -- [1]
			"Collecting Kelp", -- [2]
			7, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			253, -- [1]
			"William Pestle", -- [2]
			"Elwynn Forest", -- [3]
			43.32, -- [4]
			65.7, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[107] = {
		{
			107, -- [1]
			"Note to William", -- [2]
			6, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			248, -- [1]
			"Gramma Stonefield", -- [2]
			"Elwynn Forest", -- [3]
			34.95, -- [4]
			83.86, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26503] = {
		{
			26503, -- [1]
			"Still Assessing the Threat", -- [2]
			15, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			464, -- [1]
			"Watch Captain Parker", -- [2]
			"Redridge Mountains", -- [3]
			15.33, -- [4]
			64.59, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26505] = {
		{
			26505, -- [1]
			"Parker's Report", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			464, -- [1]
			"Watch Captain Parker", -- [2]
			"Redridge Mountains", -- [3]
			15.33, -- [4]
			64.59999999999999, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26761] = {
		{
			26761, -- [1]
			"Threat to the Kingdom", -- [2]
			15, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			234, -- [1]
			"Marshal Gryan Stoutmantle", -- [2]
			"Westfall", -- [3]
			56.37, -- [4]
			49.63, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[114] = {
		{
			114, -- [1]
			"The Escape", -- [2]
			7, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			253, -- [1]
			"William Pestle", -- [2]
			"Elwynn Forest", -- [3]
			43.32, -- [4]
			65.70999999999999, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26257] = {
		{
			26257, -- [1]
			"It's Alive!", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			233, -- [1]
			"Farmer Saldean", -- [2]
			"Westfall", -- [3]
			56.04, -- [4]
			31.23, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26513] = {
		{
			26513, -- [1]
			"Like a Fart in the Wind", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			382, -- [1]
			"Marshal Marris", -- [2]
			"Redridge Mountains", -- [3]
			31.84, -- [4]
			44.87, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[543] = {
		{
			543, -- [1]
			"The Perenolde Tiara [Group]", -- [2]
			40, -- [3]
			"Stormwind City", -- [4]
			1, -- [5]
		}, -- [1]
		{
			55, -- [1]
		}, -- [2]
		{
			2285, -- [1]
			"Count Remington Ridgewell", -- [2]
			"Stormwind City", -- [3]
			81.56, -- [4]
			34.06, -- [5]
			301, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26355] = {
		{
			26355, -- [1]
			"Captain Sanders' Hidden Treasure", -- [2]
			13, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			0, -- [1]
			"Broken Barrel", -- [2]
			"Westfall", -- [3]
			40.51, -- [4]
			47.79, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26320] = {
		{
			26320, -- [1]
			"A Vision of the Past", -- [2]
			15, -- [3]
			"Westfall", -- [4]
			1, -- [5]
		}, -- [1]
		{
			67, -- [1]
		}, -- [2]
		{
			42651, -- [1]
			"Thoralius the Wise", -- [2]
			"Westfall", -- [3]
			42.97, -- [4]
			65.02, -- [5]
			39, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[239] = {
		{
			239, -- [1]
			"Westbrook Garrison Needs Help!", -- [2]
			10, -- [3]
			"Elwynn Forest", -- [4]
			1, -- [5]
		}, -- [1]
		{
			39, -- [1]
		}, -- [2]
		{
			240, -- [1]
			"Marshal Dughan", -- [2]
			"Elwynn Forest", -- [3]
			42.11, -- [4]
			65.93000000000001, -- [5]
			30, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},
	[26506] = {
		{
			26506, -- [1]
			"Franks and Beans", -- [2]
			16, -- [3]
			"Redridge Mountains", -- [4]
			1, -- [5]
		}, -- [1]
		{
			48, -- [1]
		}, -- [2]
		{
			379, -- [1]
			"Darcy Parker", -- [2]
			"Redridge Mountains", -- [3]
			15.62, -- [4]
			65.31999999999999, -- [5]
			36, -- [6]
			0, -- [7]
			0, -- [8]
		}, -- [3]
		{
			1, -- [1]
			1, -- [2]
			32, -- [3]
		}, -- [4]
		{
		}, -- [5]
	},

}